Learn R Programming

hidecan (version 1.1.0)

.check_cols: Checks whether some columns are present in a tibble

Description

Checks whether some columns are present in a tibble

Usage

.check_cols(x, col_names, param_name = "Input data-frame")

Value

invisible NULL

Arguments

x

Tibble

col_names

character vector of column names

param_name

Character, name of the dataframe to use in the error message.