Extracts GWAS results and chromosome length from GWASpoly output.
GWAS_data_from_gwaspoly(gwaspoly_output, traits = NULL, models = NULL)A list with the following elements:
gwas_data_list: A named list of GWAS_data objects, giving the markers score for
each possible trait/genetic model combination. The names of the list are in
the form trait (genetic model).
gwas_data_thr_list: if the input data is a GWASpoly.thresh object
(from the GWASpoly::set.threshold() function), a named list of GwAS_data_thr,
with the significant markers score for each possible trait/genetic model
combination. The names of the list are in the form trait (genetic model).
chrom_length: A tibble with one row per chromosome, giving the length
(in bp) of each chromosome.
A GWASpoly.fitted or GWASpoly.thresh object
(returned by GWASpoly::GWASpoly() or GWASpoly::set.threshold() functions).
Character vector, traits for which GWAS results should be
extracted. If NULL (default value), all traits present are considered.
Character vector, genetic models for which GWAS results should be
extracted. If NULL (default value), all genetic models present are considered.